@@ -1,6 +1,7 @@
 """ABC defining properties of different LLC phases."""
 
 from abc import ABC, abstractmethod
+from typing import List, Tuple, Dict
 
 from sastools.analyzer.enums import LLCPhases, LLCSpaceGroups
 
@@ -9,7 +10,7 @@ class LLCPhase(ABC):
     """ABC defining the properties of an LLC Phase."""
 
     @abstractmethod
-    def calculate_lattice_parameters(self, d_meas: list[float]):
+    def calculate_lattice_parameters(self, d_meas: List[float]):
         ...
 
     @property
@@ -24,15 +25,15 @@ class LLCPhase(ABC):
 
     @property
     @abstractmethod
-    def miller_indices(self) -> tuple[list[int], list[int], list[int]]:
+    def miller_indices(self) -> Tuple[List[int], List[int], List[int]]:
         ...
 
     @property
     @abstractmethod
-    def lattice_parameters(self) -> list[float]:
+    def lattice_parameters(self) -> List[float]:
         ...
 
     @property
     @abstractmethod
-    def phase_information(self) -> dict:
+    def phase_information(self) -> Dict:
         ...
